pub struct Opts {
pub interfaces: Option<String>,
pub monitor_all: bool,
pub monitor_loopback: bool,
pub hide_zero_counters: bool,
pub list_interfaces: bool,
pub first_measurement: Option<f64>,
pub delay: f64,
pub count: Option<u64>,
}Fields
interfaces: Option<String>Interfaces to monitor, separated by commas (e.g., “eth0,lo”)
monitor_all: boolEnables monitoring of all interfaces found for which statistics are available.
monitor_loopback: boolEnables monitoring of loopback interfaces for which statistics are available.
hide_zero_counters: boolHides interfaces with zero counters (default false on Linux/Mac, true in Windows).
list_interfaces: boolList all available network interfaces and exit
first_measurement: Option<f64>Delay before the first measurement in seconds (must be >= 0 if set)
delay: f64Delay between updates in seconds (must be > 0)
count: Option<u64>Number of updates before stopping (must be > 0 if set)